@@ -2,24 +2,41 @@ package IO::All::Base;
 use strict;
 use warnings;
 use Fcntl;
-use XXX;
 
 sub import {
     my $class = shift;
-    my $flag = shift || '';
+    my $flag = $_[0] || '';
     my $package = caller;
     no strict 'refs';
     if ($flag eq '-base') {
         push @{$package . "::ISA"}, $class;
         *{$package . "::$_"} = \&$_
-          for qw'field const option chain proxy proxy_open XXX WWW';
+          for qw'field const option chain proxy proxy_open';
     }
     elsif ($flag eq -mixin) {
         mixin_import(scalar(caller(0)), $class, @_);
     }
     else {
-        *{$package . "::$_"} = \&{$class . "::$_"}
-          for @{$class . '::EXPORT'};
+        my @flags = @_;
+        for my $export (@{$class . '::EXPORT'}) {
+            *{$package . "::$export"} = $export eq 'io' 
+            ? $class->generate_constructor(@flags)
+            : \&{$class . "::$export"};
+        }
+    }
+}
+
+sub generate_constructor {
+    my $class = shift;
+    my @flags = grep { s/^-// } @_;
+    my $constructor;
+    $constructor = sub {
+        my $self = $class->new(@_);
+        for my $flag (@flags) {
+            $self->$flag;
+        }
+        $self->constructor($constructor);
+        return $self;
     }
 }
 
